---
title: <span class="badge object-type-scalar"></span> Sievert
---
# <span class="badge object-type-scalar"></span> Sievert

Radiation: Sievert (Sv)

## Definition

```python
# Radiation: Sievert (Sv)
Sievert: typing.Literal["radsv"] = "radsv"
```
